==> r2dbc-proxy-1.0.0.RELEASE-sources.jar: io/r2dbc/proxy/callback/ConnectionFactoryCreateMethodInvocationSubscriber.java <==
/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.r2dbc.proxy.callback;

import io.r2dbc.spi.ConnectionFactory;
import reactor.core.CoreSubscriber;

/**
 * Special subscriber for {@link ConnectionFactory#create()} to invoke before/after
 * method callbacks.
 *
 * @author Tadaya Tsuyukubo
 * @see MethodInvocationSubscriber
 * @see ConnectionFactoryCallbackHandler
 */
class ConnectionFactoryCreateMethodInvocationSubscriber extends MethodInvocationSubscriber {

    public ConnectionFactoryCreateMethodInvocationSubscriber(CoreSubscriber<Object> delegate, MutableMethodExecutionInfo executionInfo, ProxyConfig proxyConfig) {
        super(delegate, executionInfo, proxyConfig, null);
    }

    @Override
    public void onComplete() {
        // "doOnSuccess()" chained to this operator calls "afterMethod()" callback.
        // Therefore, do not call "afterMethod()" on "onComplete()" here.
        // see "ConnectionFactoryCallbackHandler" and how it handles "create" method.
        this.delegate.onComplete();
    }

}

==> r2dbc-proxy-1.1.5.RELEASE-sources.jar: io/r2dbc/proxy/callback/ConnectionFactoryCreateMethodInvocationSubscriber.java <==
/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.r2dbc.proxy.callback;

import io.r2dbc.spi.ConnectionFactory;
import reactor.core.CoreSubscriber;
import reactor.util.context.ContextView;

/**
 * Special subscriber for {@link ConnectionFactory#create()} to invoke before/after
 * method callbacks.
 *
 * @author Tadaya Tsuyukubo
 * @see MethodInvocationSubscriber
 * @see ConnectionFactoryCallbackHandler
 */
class ConnectionFactoryCreateMethodInvocationSubscriber extends MethodInvocationSubscriber {

    public ConnectionFactoryCreateMethodInvocationSubscriber(CoreSubscriber<Object> delegate, MutableMethodExecutionInfo executionInfo, ProxyConfig proxyConfig) {
        super(delegate, executionInfo, proxyConfig, null);
    }

    @Override
    public void onComplete() {
        // "doOnSuccess()" chained to this operator calls "afterMethod()" callback.
        // Therefore, do not call "afterMethod()" on "onComplete()" here.
        // see "ConnectionFactoryCallbackHandler" and how it handles "create" method.
        this.delegate.onComplete();
    }

    @Override
    protected void beforeMethod() {
        // register reactor context as read only at connection-info level
        this.executionInfo.getConnectionInfo().getValueStore().put(ContextView.class, new DelegatingContextView(currentContext()));
        super.beforeMethod();
    }
}
